@@ -47,12 +47,15 @@ fn main() {
         let ament_prefix_var = env::var(ament_prefix_var_name).expect("Source your ROS!");
 
         for ament_prefix_path in ament_prefix_var.split(':') {
-            builder = builder.clang_arg(format!("-I{}/include", ament_prefix_path));
-            println!(
-                "added include search dir: {}",
-                format!("-I{}/include", ament_prefix_path)
-            );
-            println!("cargo:rustc-link-search=native={}/lib", ament_prefix_path);
+            if let Some(include_path) = r2r_common::guess_cmake_include_path(Path::new(ament_prefix_path)) {
+                if let Some(s) = include_path.to_str() {
+                    builder = builder.clang_arg(format!("-I{}", s));
+                };
+            }
+            let lib_path = Path::new(ament_prefix_path).join("lib");
+            lib_path.to_str().map(|s| {
+                println!("cargo:rustc-link-search=native={}", s);
+            });
         }
     }
 
